Changelog
=========


1.0.0a2 (2023-11-21)
--------------------

- Add controlpanel link to the tile types overview. [fredvd]

- Show published and Private/other counts when using the tile_types_overview and
  clicking on individual tiles to see the found mosaic pages.
  [fredvd]


1.0.0a1 (2023-11-16)
--------------------

- Initial release.
  [fredvd, maurits]
